@@ -29,13 +29,12 @@
 #include "parse.h"
 
 
-void
+static int 
 cnee_handle_err(xnee_data *xd, int error)
 {
   const char *err;
   const char *descr;
 
-
   if ( error != XNEE_OK_LEAVE )
     {
       err   = xnee_get_err_description(error);
@@ -45,7 +44,6 @@ cnee_handle_err(xnee_data *xd, int error)
       fprintf (stderr, "  Error:      %s\n", err);
       fprintf (stderr, "  Solution:   %s\n", descr);
     }
-  xnee_close_down(xd);
   exit(error);
 }
 
@@ -61,7 +59,7 @@ int main(int argc,char *argv[])
 {
   int ret;
   xnee_data *xd ;
-  
+
   /*  Get a new xnee_data structure  */
   xd = xnee_new_xnee_data();
   if (xd==NULL)
@@ -84,10 +82,12 @@ int main(int argc,char *argv[])
 	{
 	  exit (XNEE_OK);
 	}
-      else 
+      else if ( ret == -1 )
 	{
-	  cnee_handle_err(xd, ret);
+	  ret = XNEE_WRONG_PARAMS;
 	}
+      fprintf(stderr, "writing crap %d\n", ret);
+      cnee_handle_err(xd, ret);
     }
 
   /* Set the cli parameters */
@@ -97,8 +97,6 @@ int main(int argc,char *argv[])
       cnee_handle_err(xd, ret);
     }
 
-
-  ret = xnee_prepare(xd);
   if (ret==XNEE_OK)
     {
       /* start up the action set during parsing the commnd line */
@@ -107,13 +105,7 @@ int main(int argc,char *argv[])
 
   if ( ret != XNEE_OK)
   {
-    xnee_print_error (PACKAGE " failed to start\n");
-    xnee_print_error ("   Error number:    %d\n", ret);
-    xnee_print_error ("   Error string:    '%s'\n", 
-		      xnee_get_err_description(ret));
-    xnee_print_error ("   Solution string: '%s'\n", 
-		      xnee_get_err_solution(ret));
-    exit(ret);
+    cnee_handle_err(xd, ret);
   }
 
 
