@@ -26,9 +26,6 @@
 
 #include <stdio.h>
 
-#include <X11/X.h>
-#include <X11/Xproto.h>
-
 #ifndef XNEE_DATASTRINGS_H 
 #define XNEE_DATASTRINGS_H 
 
