@@ -313,13 +313,16 @@ int
 xnee_set_distributor (xnee_data *xd);
  
 int
-xnee_set_retyper (xnee_data *xd);
+xnee_set_syntax_checker (xnee_data *xd);
  
 int
+xnee_set_retyper (xnee_data *xd);
+ 
+unsigned char
 xnee_get_mode (xnee_data *xd);
 
 int
-xnee_set_mode (xnee_data *xd, int mode);
+xnee_set_mode (xnee_data *xd, unsigned char mode);
 
 int
 xnee_is_recorder (xnee_data *xd);
@@ -327,6 +330,9 @@ xnee_is_recorder (xnee_data *xd);
 int
 xnee_is_replayer (xnee_data *xd);
 
+int
+xnee_is_syntax_checker (xnee_data *xd);
+ 
 int
 xnee_is_distributor (xnee_data *xd);
 
@@ -782,10 +788,24 @@ xnee_get_rep_resolution_x (xnee_data *xd);
 int
 xnee_get_rep_resolution_y (xnee_data *xd);
  
-#define xnee_set_interrupt_action(xd)  (xd->xnee_info.interrupt=1)
+#define xnee_set_interrupt_error(xd, err) \
+   (xd->xnee_info.interrupt=err)
 
-#define xnee_unset_interrupt_action(xd) (xd->xnee_info.interrupt=0)
+#define xnee_set_interrupt_action(xd)  \
+   (xd->xnee_info.interrupt=XNEE_OK_LEAVE)
 
-#define xnee_get_interrupt_action(xd) (xd->xnee_info.interrupt)
+#define xnee_unset_interrupt_action(xd) \
+   (xd->xnee_info.interrupt=XNEE_OK)
+
+#define xnee_get_interrupt_action(xd) \
+   (xd->xnee_info.interrupt)
+
+#define xnee_is_interrupt_action(xd) \
+   (xd->xnee_info.interrupt!=XNEE_OK)
+xnee_data*
+xnee_get_xnee_data (void);
+
+int
+xnee_set_xnee_data (xnee_data *xd);
 
 #endif /* XNEE_SETGET_H */ 
