@@ -25,8 +25,6 @@
 
 #include <stdio.h>
 
-#include <X11/X.h>
-#include <X11/Xproto.h>
 #include <libxnee/datastrings.h>
 #include "libxnee/xnee.h"
 
