@@ -38,6 +38,8 @@
 
 
 
+static xnee_data *xd_saved;
+
 int
 xnee_set_display_name (xnee_data *xd, const char *disp)
 {
@@ -436,6 +438,13 @@ xnee_set_distributor (xnee_data *xd)
 }
  
 
+int
+xnee_set_syntax_checker (xnee_data *xd)
+{
+  xd->mode=XNEE_SYNTAX_CHECKER;
+  return XNEE_OK;
+}
+ 
 int
 xnee_set_retyper (xnee_data *xd)
 {
@@ -444,14 +453,14 @@ xnee_set_retyper (xnee_data *xd)
 }
  
 
-int
+unsigned char 
 xnee_get_mode (xnee_data *xd)
 {
   return xd->mode;
 }
 
 int
-xnee_set_mode (xnee_data *xd, int mode)
+xnee_set_mode (xnee_data *xd, unsigned char mode)
 {
   xd->mode=mode;
   return XNEE_OK;
@@ -463,6 +472,12 @@ xnee_is_recorder (xnee_data *xd)
   return (xd->mode==XNEE_RECORDER);
 }
 
+int
+xnee_is_syntax_checker (xnee_data *xd)
+{
+  return (xd->mode==XNEE_SYNTAX_CHECKER);
+}
+ 
 int
 xnee_is_replayer (xnee_data *xd)
 {
@@ -1163,7 +1178,7 @@ xnee_set_recall_window_pos (xnee_data *xd)
 {
   xnee_verbose((xd, "xnee_set_recall_window_pos()\n"));
   xd->recall_recorded_win_pos=1;
-  return XNEE_OK;
+  return xnee_parse_range (xd, XNEE_DELIVERED_EVENT, "ReparentNotify");
 }
 
 
@@ -1206,10 +1221,9 @@ xnee_set_project_file(xnee_data *xd, char *name)
       xnee_verbose((xd, "\ttryingresource file %s\n", buf));
       ret = xnee_set_rc_name (xd, buf);
     }
-	  
   if ( xnee_get_rc_file (xd) != NULL) 
     {
-      ret = xnee_add_resource (xd );
+      ret = xnee_add_resource (xd);
 	      
       if (ret!=XNEE_OK)
 	{
@@ -1220,8 +1234,12 @@ xnee_set_project_file(xnee_data *xd, char *name)
 	      char *tmp_str;
 	      xnee_verbose ((xd, "project file read: SYNTAX ERROR\n"));
 	      tmp_str = xnee_get_err_string();
-	      fprintf (stderr,"%s", tmp_str);
+	      if (tmp_str!=NULL)
+		{
+		  fprintf (stderr,"%s", tmp_str);
+		}
 	      XNEE_FREE_IF_NOT_NULL(tmp_str);
+	      return ret;
 	    }
 	}
     }
@@ -1765,3 +1783,15 @@ xnee_get_rep_resolution_y (xnee_data *xd)
   return xd->res_info.replay.y_res;
 }
  
+xnee_data*
+xnee_get_xnee_data (void)
+{
+  return xd_saved;
+}
+
+int
+xnee_set_xnee_data (xnee_data *xd)
+{
+  xd_saved = xd;
+}
+ 
