@@ -174,8 +174,17 @@ void
 pnee_set_interval (GtkToggleButton *togglebutton,
 		   gpointer         user_data);
 
-#endif /* CALLBACKS_H */
-
 void
 on_log_file_button_clicked             (GtkButton       *button,
                                         gpointer         user_data);
+
+void
+on_error_ok_clicked                    (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+pnee_set_events_to_record (GtkToggleButton *togglebutton,
+			   gpointer         user_data);
+
+#endif /* CALLBACKS_H */
+
